#ifdef BACKEND_DJGPP


#include "djgpp.h"


FontT *__font8x14 = NULL;


void fontWrite(char *message, int16_t x, int16_t y, FontT *font, ColorT foreground, ColorT background) {

}


SurfaceT *imageLoad(char *filename) {
	SurfaceT *image = NULL;

	return image;
}


void platformEventGet(EventT *event) {

}


void platformShutdown(void) {

}


void platformStartup(int16_t width, int16_t height, int16_t depth) {

}

uint16_t videoDisplayHeightGet(void) {
	return 0;
}


uint16_t videoDisplayWidthGet(void) {
	return 0;
}


void videoModesShow(void) {

}


void videoSurfaceBlit(SurfaceT *target, int16_t targetX, int16_t targetY, SurfaceT *source) {

}


void videoSurfaceBlitWithTransparency(SurfaceT *target, int16_t targetX, int16_t targetY, SurfaceT *source, ColorT transparent) {

}


void videoSurfaceClear(ColorT color) {

}


SurfaceT *videoSurfaceCreate(int16_t width, int16_t height) {
	SurfaceT *surface = NULL;

	return surface;
}


void videoSurfaceDestroy(SurfaceT *surface) {

}


void videoSurfaceBox(int16_t x1, int16_t y1, int16_t x2, int16_t y2, ColorT c) {

}


void videoSurfaceBoxFilled(int16_t x1, int16_t y1, int16_t x2, int16_t y2, ColorT c) {

}


int16_t videoSurfaceHeightGet(SurfaceT *surface) {
	return surface->height;
}


void videoSurfaceLineH(int16_t x1, int16_t y1, int16_t x, ColorT c) {

}


void videoSurfaceLineV(int16_t x, int16_t x2, int16_t y2, ColorT c) {

}


ColorT videoSurfacePixelGet(SurfaceT *surface, int16_t x, int16_t y) {
	return 0;
}


void videoSurfacePixelSet(int16_t x, int16_t y, ColorT c) {

}


void videoSurfaceSet(SurfaceT *surface) {

}


SurfaceT *videoSurfaceScreenGet(void) {
	return NULL;
}


int16_t videoSurfaceWidthGet(SurfaceT *surface) {
	return surface->width;
}


#endif  // BACKEND_DJGPP
